function [comp]=addvals(comp)
% function [comp]=addvals(comp)
% adds the information to comp that was previously obtained by running 
% a (vb) simulation of combined systems analysis.
% Simulation results are expected to be stored in comp.simfname.
% IN : comp
% here we modify:
% comp.indP         all indicator probabilities for "use subset" (i.e. in favour of using a gene).
%                   note that the last entry is for "no gene vs. no gene" and thus 0.5. This is 
%                   necessary as we need to have as many entries as we have in the gene measure across all and that
%                   includes the empty subset.
% comp.subsP        Probability measure accross genes.
% comp.havefolds    boolean information that is true if we have fold results 
%                   (set automatically from information in comp.simfname) 
% comp.fldidPs      fold probabilities of indicator variables
% comp.fldmsrPs     fold probability measures accross genes
% comp.sysifo       system info for each dataset contributing to a comparison.
% sysinfo.genPclss  generalization Probabilities of class labels (from fold testing and/or separate test data)
% sysinfo.gentrg    true targets (from fold testing and/or separate test data) gentrg may be nan if such are 
%                   not available. In this case we plot probabilities but do not calculate generalization accuracies.
% sysinfo.preds     known training labels and predicted probabilities for nan's in training data.
%                   preds are extracted from the results stored for the corresponding system in comp.simfname.
%                   if unavailable, this is an empty array. Then the following info including the plot description
%                   is ignored (and may be missing or empty).
% sysinfo.dx4plot   plot indices of corresponding entries in preds. This needs to match preds!
%                   e.g.: 2 repetitions in each main effect (i.e. two repetitions per time point).
%                   species(1).dx4plot=[1 1 2 2 3 3 4 4 5 5 6 6 7 7 8 8 9 9 10 10 11 11 12 12]';
% if havefolds
%   save(resfname, 'vbprb', 'subsprobs', 'indprobs', 'Pclass', 'truetargs', 'gtargs', 'alltrdx', 'alltsdx', 'havefolds', 'foldpred');
% else
%   save(resfname, 'vbprb', 'subsprobs', 'indprobs', 'Pclass', 'truetargs', 'gtargs', 'alltrdx', 'alltsdx', 'havefolds');
% end

comp.subsP=sload(comp.simfname, 'subsprobs', 1);
% indicatpr probabilities - add 0.5 for the empty subset
comp.indP=[sload(comp.simfname, 'indprobs', 1), 0.5];
Pclass=sload(comp.simfname, 'Pclass', 1);
alltrdx=sload(comp.simfname, 'alltrdx', 1);
alltsdx=sload(comp.simfname, 'alltsdx', 1);
alltruetargs=sload(comp.simfname, 'truetargs', 1);
alltraintarg=sload(comp.simfname, 'alltraintarg', 1);
havefolds=sload(comp.simfname, 'havefolds', 1);
comp.havefolds=havefolds;
if havefolds
    [foldpred]=sload(comp.simfname, 'foldpred', 1);
    % also store at this location the fold indicator probabilities and the
    % fold gene measures
    comp.fldidPs=foldpred(1).findP;
    % add the 0.5 for the empty subset
    comp.fldidPs=[comp.fldidPs, ones(size(comp.fldidPs, 1), 1)*0.5];    
    % and gene measure into the other store
    comp.fldmsrPs=foldpred(1).fsubsP;
end
nsys=length(Pclass);
for n=1:nsys
    %n
    comp.sysinfo(n).trantarg=alltraintarg{n};
    % initialize sysinfo.pred (this is the training labels and all classifications on
    % nan parts in the training data. Used to visualise the probabilities of unknown states 
    % within the training data - most appropriate in time course data.
    tsdx=alltsdx{n};
    Pcs=Pclass{n};
    if ~isempty(tsdx)
        lbls=zeros(length(alltrdx{n})+length(alltsdx{n}), 1);
        lbls(alltrdx{n})=comp.sysinfo(n).trantarg;
        %trdx=alltrdx{n};
        if size(Pcs, 2)>1
            Pcs=Pcs(:,2);
        end
        alldat=lbls;
        alldat(tsdx)=Pcs(1:length(tsdx),1);
        comp.sysinfo(n).preds=alldat;
    else
        comp.sysinfo(n).preds=[];
    end
    % initialize generalization predictions from test data (excluding nan's in training data) and
    % from fold testing.
    Pclss=Pclass{n};
    %size(Pclss)
    truetargs=alltruetargs{n};
    if size(Pclss, 1)>length(alltsdx{n}) % then there are predictions for test data available
        testdx=[(length(alltsdx)+1):size(Pclss, 1)]';
        comp.sysinfo(n).genPclss = Pclss(testdx,:);
        comp.sysinfo(n).gentrg = truetargs(testdx, 1);
    else
        comp.sysinfo(n).genPclss = [];
        comp.sysinfo(n).gentrg = [];
    end
    if havefolds
        % we add the fold predictions and the true targets to genPclss and gentrg
        comp.sysinfo(n).genPclss = [comp.sysinfo(n).genPclss; foldpred(n).fPclss];
        comp.sysinfo(n).gentrg = [comp.sysinfo(n).gentrg;foldpred(n).ftruetargs];
    end
end
% finally add system distance information (this is robust to old version runs
% where that might not be available)
[comp]=add_sys_klP(comp);