function combres2csvfile(comp)
% function combres2figtab(comp)
% converts the result of a comparison into a csv file.
% (C) P. Sykacek 2005,2006
% input:
% comp              describes the comparison
% comp.genespec     cell array with first column containing a short description (gene symbols)
%                   andsecond column containing a long description.
% comp.interspec    is a corresponding description for the empty subset
%                   e.g comp.interspec={'no gene', 'no gene - prediction from intercept', '---'};
% comp.simfname     file name that contains all simulation results. (from which we get all probability measures and the
%                   generalisation accuracies).
% comp.rankinfo     information that specifies how rank information is written into the latex table and into the file 
% rankinfo.header   header line in file and latex table
% rankinfo.fname    file name of csv file that stores all gene symbols, gene desciptions and both probabilty measures.
% rankinfo.csvfileid column indices that go into the csv file.
%                     (for the concerned information refer to the header.)
% functions used in the context of combres2csvfile.m:
% addvals.m -> initialises those comp elements that are obtained from simulation and stored in the file
% comp.simfname.
% genranktab -> generates a rank list (cell array) that contains gene symbols and gene descriptions in the first two 
% columns, the indicator probability, gene measure (accross genes) and the cumulatiove gene measure in columns 3 to 5. 
% rankgenes2file -> writes rank list into a file

haveoct=syschck('oct');
% first convert new gene description format into the old one we use here.
[comp.genespec]=annoconv_newvb2old(comp.genespec);
if isfield(comp, 'spikespec')
    comp.spikespec=comp.spikespec(:,[2,3]);
end

ncomp=length(comp);
for n=1:ncomp
    % first we initialises those comp elements that are obtained from simulation and stored in the file
    % comp.simfname.
    comp=addvals(comp);
    % modification: load vbprb
    [vbprb]=sload(comp(n).simfname, 'vbprb', 1);
    % add a section for that comparison
    nsys=length(comp(n).sysinfo);
    % now we add temporary at the last entry in genespec an entry for the
    % empty array:
    if isfield(comp, 'spikespec')
        comp(n).genespec=[comp(n).genespec; comp(n).interspec; comp(n).spikespec];
    else
        comp(n).genespec=[comp(n).genespec; comp(n).interspec];
    end
    % next we need to obtain the rank list of the comparison
    % we use here the mode that generates a functional coexpression flag
    [ranklist, id, coexpressed]=genranktab(comp(n), 1, vbprb);
    % new: if available we generate a table of kl-distances between the overall
    % indicator probabilities and the system specific ones ranked w.r.t. 
    % the id returned from ranking (goes eventually into latex table and definitely to file.
    if comp(n).have_sys_klP
        %klsyslist=comp.KLsysind';
        % we actually want here the individual indicator probabilities
        % in favour of gene function since they are easier to understand.
        klsyslist=squeeze(comp(n).P_sysind(2,:,:));
        %[r,c]=size(klsyslist);
        %klsyslist=[klsyslist; nan*ones(1,c)];
        klsyslist=num2cell(klsyslist(id,:));
    else
        klsyslist={};
    end
    if isfield(comp(n), 'deffilename')
        [allsysobs]=get_expdata(comp(n).deffilename, id, vbprb);
        [meandata]=data_2_expect(allsysobs, comp(n).expfun);
        meandiff=sum(meandata(:,:,2)-meandata(:,:,1), 2);
        upreg=sign(meandiff)==1;
        coregifo={'anti', 'co'};
        coregifo=coregifo(1+coexpressed);
        coregifo=coregifo(:);
        upregifo={'down', 'up'};
        upregifo=upregifo(1+upreg);
        upregifo=upregifo(:);
        idanti=find(~coexpressed);
        for nanti=1:length(idanti)
            upregifo{idanti(nanti)}='diff';
        end
        coregifo=[coregifo, upregifo];
    else
        coregifo={'anti', 'co'};
        coregifo=coregifo(1+coexpressed);
        coregifo=coregifo(:);
    end
    ranklist=[ranklist, coregifo, klsyslist];
    % now we add all comparison based informations:
    % the rank table that gets written as a csv file.
    rankgenes2file(comp(n), ranklist);
end
  