function [meandata]=data_2_expect(allsysobs, fun)
% function [meandata]=data_2_expect(allsysobs, fun)
% calculates the sample mean of all entries in allsysobs.
% IN
% allsysobs:    (log [ratio]) gene expressions of all 
%               transcripts (and zeros for the empty sybset)
%               [no transcripts x no systems x no targets]
% OUT
% meandata:     sample mean of the above cell entries.
%
% (C) P. Sykacek 2005

if nargin<2
    fun=@mean;
end

[ntrans, nsys, ntrgs]=size(allsysobs);
meandata=zeros(ntrans, nsys, ntrgs);
for nt=1:ntrans
    for ns=1:nsys
        for n=1:ntrgs
            if isempty(allsysobs{nt, ns, n})
                disp(sprintf('[] allsysobs in trans no:%d sys no: %d trg no: %d', nt, ns, n));
            end
            meandata(nt, ns, n)=fun(allsysobs{nt, ns, n});
        end
    end
end