function [allsysobs]=get_expdata(deffile, id, vbprb)
% function [allsysobs]=get_expdata(deffile, id, vbprb)
% calculates an ordered table of means. Each target in the
% list gets its own array. (see meantab) 
% IN
% deffile: the deffile used for inference.
% id:      index for ordering the subsets w.r.t. the probability measure.
% vbprb:   infered vbprb structure (for refsubsno)
% OUT
% NOT HERE ! meantab: three dimensional array: [nsubsets x nsystems x ntragets]
% allsysobs: (log [ratio]) gene expressions per class label and system.
%            the data is reordered w.r.t. id.
%            [no transcripts x no systems x no classes]
%
% (C) P. Sykacek 2005 (to test for coexpression).

[subsets, allsystrain, allsystest, alltrdx, alltsdx]=prep_msys(deffile, 0);
[allspikedata]=getspikes(deffile, alltrdx);
for n=1:length(allsystrain);
    thisdat=allsystrain{n};
    size(thisdat)
    size(allspikedata{n})
    allsystrain{n}=[thisdat(:, 1:(size(thisdat,2)-1)), allspikedata{n}, thisdat(:, size(thisdat, 2))];
end
nsys=length(vbprb.sys);
ntrans=length(vbprb.sys(1).g_mdls)+1; % we have one more transcripts than entries since one is compared against.
nrefc=vbprb.refsubspos;
dt=allsystrain{1};
dt=dt(:, size(dt,2));
ntrg=max(dt)-min(dt)+1;
allsysobs=cell(ntrans, nsys, ntrg); 
for sct=1:nsys
    data=allsystrain{sct};
    for trct=1:ntrg
        idthis=find(data(:, size(data,2))==(trct-1));
        idthis=idthis(:);
        for n=1:ntrans
            if n < nrefc    % below reference subsetnumber and position in indprobs and subsprobs is the same as subset number
                pos=n;
                datcol=vbprb.sys(sct).g_mdls(pos).i_mdl(2).subs;
                if ~isempty(datcol)
                    allsysobs{n, sct, trct}=data(idthis, datcol);
                else
                    allsysobs{n, sct, trct}=zeros(size(idthis));
                end
            elseif n==nrefc % equal to reference subset. position is still n but the coefficients are ar i_mdl(1). (any transcript index!)
                pos=1;
                datcol=vbprb.sys(sct).g_mdls(pos).i_mdl(1).subs;
                if ~isempty(datcol)
                    allsysobs{n, sct, trct}=data(idthis, datcol);
                else
                    allsysobs{n, sct, trct}=zeros(size(idthis));
                end
            else % larger than reference subset: pos in indprobs is one abopve subset number!
                pos=n-1;
                datcol=vbprb.sys(sct).g_mdls(pos).i_mdl(2).subs;
                if ~isempty(datcol)
                    allsysobs{n, sct, trct}=data(idthis, datcol);
                else
                    allsysobs{n, sct, trct}=zeros(size(idthis));
                end               
            end
        end
    end
end
% finally we reorder the data such that they match the id!
allsysobs=allsysobs(id,:,:);